#  aws-monitor

A python package for monitoring AWS resources.

## Features

- Monitor AWS Cost By Period & Service, Linked Account
- onitor AWS Cost  to monitor Service by Linked Account
- Graphs

## Installation

```bash
pip install aws-monitor==0.4
